@@ -792,6 +792,7 @@ fe_dcc_open_recv_win (int passive)
 	GtkWidget *radio, *table, *vbox, *bbox, *view, *exp, *detailbox;
 	GtkListStore *store;
 	GSList *group;
+	char buf[128];
 
 	if (dccfwin.window)
 	{
@@ -799,9 +800,9 @@ fe_dcc_open_recv_win (int passive)
 			mg_bring_tofront (dccfwin.window);
 		return TRUE;
 	}
-	dccfwin.window = mg_create_generic_tab ("Transfers", _(DISPLAY_NAME": Uploads and Downloads"),
-														 FALSE, TRUE, close_dcc_file_window, NULL,
-														 win_width, win_height, &vbox, 0);
+	g_snprintf(buf, sizeof(buf), _("Uploads and Downloads - %s"), _(DISPLAY_NAME));
+	dccfwin.window = mg_create_generic_tab ("Transfers", buf, FALSE, TRUE, close_dcc_file_window,
+														 NULL, win_width, win_height, &vbox, 0);
 	gtkutil_destroy_on_esc (dccfwin.window);
 	gtk_container_set_border_width (GTK_CONTAINER (dccfwin.window), 3);
 	gtk_box_set_spacing (GTK_BOX (vbox), 3);
@@ -1037,6 +1038,7 @@ fe_dcc_open_chat_win (int passive)
 {
 	GtkWidget *view, *vbox, *bbox;
 	GtkListStore *store;
+	char buf[128];
 
 	if (dcccwin.window)
 	{
@@ -1045,9 +1047,10 @@ fe_dcc_open_chat_win (int passive)
 		return TRUE;
 	}
 
+	g_snprintf(buf, sizeof(buf), _("DCC Chat List - %s"), _(DISPLAY_NAME));
 	dcccwin.window =
-			  mg_create_generic_tab ("DCCChat", _(DISPLAY_NAME": DCC Chat List"),
-						FALSE, TRUE, dcc_chat_close_cb, NULL, 550, 180, &vbox, 0);
+			  mg_create_generic_tab ("DCCChat", buf, FALSE, TRUE, dcc_chat_close_cb,
+						NULL, 550, 180, &vbox, 0);
 	gtkutil_destroy_on_esc (dcccwin.window);
 	gtk_container_set_border_width (GTK_CONTAINER (dcccwin.window), 3);
 	gtk_box_set_spacing (GTK_BOX (vbox), 3);
