@@ -216,9 +216,9 @@ struct _GtkXText
 
 	/* various state information */
 	unsigned int moving_separator:1;
-	unsigned int word_or_line_select:1;
+	unsigned int word_select:1;
+	unsigned int line_select:1;
 	unsigned int button_down:1;
-	unsigned int hilighting:1;
 	unsigned int dont_render:1;
 	unsigned int dont_render2:1;
 	unsigned int cursor_hand:1;
@@ -251,7 +251,7 @@ struct _GtkXTextClass
 };
 
 GtkWidget *gtk_xtext_new (GdkColor palette[], int separator);
-void gtk_xtext_append (xtext_buffer *buf, unsigned char *text, int len);
+void gtk_xtext_append (xtext_buffer *buf, unsigned char *text, int len, time_t stamp);
 void gtk_xtext_append_indent (xtext_buffer *buf,
 										unsigned char *left_text, int left_len,
 										unsigned char *right_text, int right_len,
